<?php
/** @var App\Models\Note $note */
/** @var App\Models\Pro $pro */
/** @var App\Models\Section $section */
/** @var $allSections */
?>
@extends ('layouts.patient')

@section('inner-content')

    <?php
    $hasBills = false;
    if($note->bills->count()) {
        foreach ($note->bills as $bill) {
            if(!$bill->is_cancelled) {
                $hasBills = true;
                break;
            }
        }
    }
    ?>

    <div class="pt-2 pb-3 d-flex align-items-start">
        <h6 class="my-0 text-secondary d-flex align-items-start w-100">
            <a href="/patients/view/{{ $patient->uid }}/notes" class="small text-decoration-none mr-3">
                <i class="fa fa-chevron-left"></i>
            </a>
            <div class="mr-auto">
                <span class="text-dark font-weight-bold">Note
                    <span class="text-secondary font-weight-normal">{{ $note->is_cancelled ? '(CANCELLED)' : '' }}</span>
                </span>
            </div>
            @if($patient->has_mcp_done_onboarding_visit !== 'YES')
                <div class="ml-auto">
                    <div moe relative>
                        <a start show class="font-weight-bold">Mark as Onboarding Visit Note</a>
                        <form url="/api/client/updateMcpOnboardingVisitInfo" class="mcp-theme-1" right>
                            <input type="hidden" name="uid" value="{{$patient->uid}}">
                            <input type="hidden" name="mcpOnboardingVisitNoteUid" value="{{$note->uid}}">
                            <input type="hidden" name="hasMcpDoneOnboardingVisit" value="YES">
                            <input type="hidden" name="mcpOnboardingVisitDate" value="{{$note->effective_dateest}}">
                            <p class="min-width-200px">Mark this patient's onboarding as completed using this note?</p>
                            <div>
                                <button submit class="btn btn-sm btn-success mr-1">Yes</button>
                                <button cancel class="btn btn-sm btn-default border">No</button>
                            </div>
                        </form>
                    </div>

                </div>
            @endif
        </h6>
    </div>

    <div class="card mb-0 {{ $note->is_cancelled ? 'cancelled-item' : '' }}">
        <div class="card-header d-flex align-items-start px-3 py-2 border-bottom">
            <div class="pr-2">
                {{$note->title}}
                @if(!$note->is_signed_by_hcp)
                <div moe>
                    <a href="" show start><i class="fa fa-edit"></i></a>
                    <form url="/api/note/putTitle">
                        <input type="hidden" name="uid" value="{{$note->uid}}">
                        <div class="mb-2">
                            <input type="text" name="title" value="{{$note->title}}" class="form-control form-control-sm"
                                   placeholder="Title">
                        </div>
                        <div class="form-group mb-0">
                            <button class="btn btn-primary btn-sm" submit>Submit</button>
                            <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                        </div>
                    </form>
                </div>
                @endif
            </div>
            <div class="px-2 border-left border-right">
                <div class="d-flex">
                    <span class="mr-2">{{friendly_date_time($note->effective_dateest, false, '')}}</span>
                    @if(!$note->is_signed_by_hcp)
                    <span moe class="ml-auto">
                        <a href="" show start><i class="fa fa-calendar"></i></a>
                        <form url="/api/note/putEffectiveDateEST">
                            <input type="hidden" name="uid" value="{{$note->uid}}">
                            <div class="mb-2">
                                <label for="" class="text-secondary text-sm">Effective date EST</label>
                                <input type="date" name="effectiveDateEST" value="{{$note->effective_dateest}}" class="form-control form-control-sm">
                            </div>
                            <div class="mb-0">
                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                            </div>
                        </form>
                    </span>
                    @endif
                </div>
                <div class="d-flex">
                    <span class="mr-2">{{friendly_time($note->effective_time, '')}}</span>
                    @if(!$note->is_signed_by_hcp)
                    <span moe class="ml-auto">
                        <a href="" show start><i class="fa fa-clock"></i></a>
                        <form url="/api/note/putEffectiveTime">
                            <input type="hidden" name="uid" value="{{$note->uid}}">
                            <div class="mb-2">
                                <label for="" class="text-secondary text-sm">Effective time </label>
                                <input type="time" name="effectiveTime" value="{{ date("H:i", strtotime($note->effective_time)) }}" class="form-control form-control-sm">
                            </div>
                            <div class="mb-0">
                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                            </div>
                        </form>
                    </span>
                    @endif
                </div>
            </div>

            <div class="px-2">
                <div class="d-flex">
                    <span class="mr-2"><span class="text-secondary">HCP:</span> {{$note->hcpPro->name_display}}</span>
                    @if(!$note->is_signed_by_hcp)
                    <div moe class="ml-auto">
                        <a href="" show start><i class="fa fa-edit"></i></a>
                        <form url="/api/note/putHcp">
                            <input type="hidden" name="uid" value="{{$note->uid}}">
                            <div class="mb-2">
                                <select name="hcpProUid" class="form-control form-control-sm">
                                    <option value="">-- Select HCP Pro --</option>
                                    @foreach ($pros as $iPro)
                                        <option value="{{$iPro->uid}}" {{ $note->hcpPro && $iPro->id === $note->hcpPro->id ? 'selected' : '' }}>{{$iPro->name_display}}</option>
                                    @endforeach
                                </select>
                            </div>
                            <div class="mb-0">
                                <button class="btn btn-primary btn-sm" submit>Submit</button>
                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                            </div>
                        </form>
                    </div>
                    @endif
                </div>
            </div>
            <div class="ml-auto d-flex align-items-start">
                <div class="pr-2">
                    <div>
                        @if($note->is_signed_by_hcp)
                            <span class="text-secondary">
                        <i class="fa fa-check"></i>
                        HCP Signed
                    </span>
                        @else
                            <div moe
                                 class="{{ $note->hcp_pro_id !== $pro->id ? 'moe-disabled' : '' }}"
                                 title="{{ $note->hcp_pro_id !== $pro->id ? 'Only the note\'s HCP can sign' : '' }}">
                                <a class="" href="" show start>Sign as HCP</a>
                                <form url="/api/note/signAsHcp">
                                    <input type="hidden" name="uid" value="{{$note->uid}}">
                                    <p>Sign this note as HCP?</p>
                                    <div class="mb-0">
                                        <button class="btn btn-success btn-sm" submit>Sign</button>
                                        <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                    </div>
                                </form>
                            </div>
                        @endif
                    </div>
                </div>
                <div class="pl-2 border-left">
                    @if($patient->has_mcp_done_onboarding_visit === 'YES')
                    <div class="d-flex justify-content-end">
                        <div moe relatve class="">
                            <a class="" href="" show start>Create Bill</a>
                            <form url="/api/bill/createForNote" right>
                                <input type="hidden" name="noteUid" value="{{$note->uid}}">
                                <div class="mb-2">
                                    <label for="" class="text-secondary text-sm">Effective Date</label>
                                    <input type="date" name="effectiveDate" class="form-control form-control-sm" value="{{date('Y-m-d')}}" required>
                                </div>
                                <div class="mb-2">
                                    <select autofocus class="form-control" name="code">
                                        <option value="">-- Select Code --</option>
                                        <?php $noteRates = $pro->noteRates(); ?>
                                        @if($noteRates && count($noteRates))
                                            @foreach($noteRates as $noteRate)
                                                <option value="{{ $noteRate->code }}">{{ $noteRate->code }}</option>
                                            @endforeach
                                        @endif
                                    </select>
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason1" placeholder="Reason 1" class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason2" placeholder="Reason 2" class="form-control form-control-sm">
                                </div>
                                <div class="">
                                    <button class="btn btn-primary btn-sm" submit>Submit</button>
                                    <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                </div>
                            </form>
                        </div>
                    </div>
                    @endif
                    <div class="d-flex justify-content-end">
                        @if(!$note->is_cancelled)
                        <div moe relatve
                             class="{{ $hasBills ? 'moe-disabled' : '' }}"
                             title="{{ $hasBills ? 'Cannot cancel note since it has un-cancelled bills in it' : '' }}">
                            <a class="text-danger" href="" show start>Cancel Note</a>
                            <form url="/api/note/cancel" right>
                                <input type="hidden" name="uid" value="{{$note->uid}}">
                                <p class="small mb-2">Are you sure you want to cancel this note?</p>
                                <div class="mb-2">
                                    <textarea name="memo" id="" cols="30" rows="5" placeholder="Memo" class="memo-textarea form-control form-control-sm"></textarea>
                                </div>
                                <div class="d-flex align-items-center">
                                    <button class="btn btn-sm btn-danger mr-2" submit>Yes</button>
                                    <button class="btn btn-sm btn-default mr-2 border" cancel>No</button>
                                </div>
                            </form>
                        </div>
                        @else
                            <span class="text-secondary font-weight-bold">CANCELLED</span>
                        @endif
                    </div>
                </div>
            </div>
        </div>
        <div class="card-body p-0">
            <div>
                <?php
                function _renderNoteTemplate($template, $topLevel) {
                    echo
                        '<div class="note-template-item" ' .
                            'template="' . (isset($template->template) ? $template->template : $template->text) . '" ' .
                            'type="' . (isset($template->type) ? $template->type : "value") . '" ' .
                            '>' .
                            '<div class="note-template-text d-flex align-items-center">' .
                                '<span class="label">' .
                                '<input type="checkbox" />' .
                                '<span>' . $template->text . '</span>' .
                                '</span>';
                            if(isset($template->type) && $template->type === 'plus-minus') {
                                echo '<div class="ml-auto mr-2 text-nowrap">';
                                echo '<a href="#" class="plus-trigger"><i class="fa fa-plus-circle"></i></a>';
                                echo '<a href="#" class="minus-trigger ml-1"><i class="fa fa-minus-circle"></i></a>';
                                echo '</div>';
                            }
                            echo '</div>';
                    if(isset($template->children) && count($template->children)) {
                        echo '<i class="fa fa-chevron-right has-children"></i>';
                        echo '<div class="note-template-children">';
                        foreach ($template->children as $t) {
                            _renderNoteTemplate($t, false);
                        }
                        echo '</div>';
                    }
                    else if(isset($template->type) && $template->type !== 'plus-minus') {
                        echo '<i class="fa fa-chevron-right has-children"></i>';
                        echo '<div class="note-template-children">';
                        if($template->type === 'alpha') {
                            echo '<textarea class="form-control form-control-sm"></textarea>';
                        }
                        else {
                            echo '<input type="' . $template->type . '" class="form-control form-control-sm">';
                        }
                        echo '</div>';
                    }
                    echo '</div>';
                }

                function renderNoteTemplates($path) {
                    $templates = json_decode(file_get_contents($path));
                    echo '<div class="note-template-container">';
                    echo '<div class="position-relative w-100">' .
                            '<div class="note-template-output">' .
                                '<div class="font-weight-bold text-secondary">Result:</div>' .
                                '<div class="note-template-output-text"></div>' .
                            '</div>' .
                            '<div class="note-template-buttons d-flex align-items-center">' .
                                '<button class="btn btn-sm btn-default bg-white border text-primary border-primary note-template-apply-trigger">Apply</button>' .
                                '<button class="btn btn-sm btn-default bg-light border text-secondary border-secondary note-template-close-trigger">Close</button>' .
                            '</div>' .
                        '</div>';
                    foreach ($templates->templates as $template) {
                        _renderNoteTemplate($template, true);
                    }
                    echo '</div>';
                }
                ?>
                <div class="mb-3">
                    <div>
                        <?php
                        $shortcuts = $pro->shortcuts;
                        $packed = [];
                        foreach ($shortcuts as $shortcut) {
                            $packed[] = $shortcut->shortcut . '|||' . $shortcut->text;
                        }
                        $packed = implode("^^^", $packed);
                        $shortcuts = $packed;
                        ?>
                        {{--<div class="primary-form">
                            <div class="note-content {{ $note->is_cancelled ? 'cancelled' : '' }} {{ $note->is_signed_by_hcp ? 'readonly' : '' }}"
                                 data-note-uid="{{ $note->uid  }}"
                                 {{ !$note->is_cancelled && empty($note->free_text_html) ? 'auto-edit' : '' }}
                                 data-shortcuts="{{ $packed }}"
                            >{!! $note->free_text_html !!}</div>
                        </div>--}}
                        @foreach($note->sections as $section)
                        <div class="p-3 border-bottom note-section">
                            <div class="d-flex align-items-start">
                                <a class="font-weight-bold mb-2 d-flex align-items-center c-pointer edit-trigger">
                                    {{$section->sectionTemplate->title}}
                                    <span class="d-none if-not-edit"><i class="fa fa-edit ml-2"></i></span>
                                </a>
                                <?php
                                if(file_exists(storage_path('sections/'.$section->sectionTemplate->internal_name.'/templates.json'))) {
                                    echo '<span class="position-relative d-none if-edit ml-3 pl-3 border-left">' .
                                        '<a href="#" class="note-templates-trigger">Templates</a>';
                                    renderNoteTemplates(storage_path('sections/'.$section->sectionTemplate->internal_name.'/templates.json'));
                                    echo '</span>';
                                }
                            ?>
                            </div>
                            <div class="d-none if-not-edit  inset-comment">{!! !empty($section->summary_html) ? $section->summary_html : '-' !!}</div>
                            <div class="d-none if-edit">@include('sections/'.$section->sectionTemplate->internal_name.'/form')</div>
                        </div>
                        @endforeach
                    </div>
                </div>

                @if($note->bills->count())
                    <div class="mt-2 px-3">
                        <p class="font-weight-bold mb-2 text-secondary">Bills</p>
                        <table class="table table-sm tabe-striped mb-3 border-left border-right border-bottom">
                            <thead class="bg-light">
                            <tr>
                                <th class="border-bottom-0 w-25 pl-3">Code</th>
                                <th class="border-bottom-0 w-25 pl-2">Reason</th>
                                <th class="border-bottom-0 w-25 pl-2">Amount</th>
                                <th class="border-bottom-0"></th>
                            </tr>
                            </thead>
                            <tbody>
                            @foreach ($note->bills as $bill)
                                <tr>
                                    <td class="pl-3 {{ $bill->is_cancelled ? 'text-secondary' : '' }}">{{$bill->code}}</td>
                                    <td class="pl-2">
                                        {{ $bill->reason1 }}
                                        <div class="text-secondary small">{{ $bill->reason2 }}</div>
                                    </td>
                                    <td class="pl-2">
                                        @if($bill->has_hcp_been_paid)
                                            <span class="text-dark">Received:</span><span class="font-weight-bold text-success ml-2">${{ $bill->hcp_payment_amount }}</span>
                                        @else
                                            <span class="text-dark">Expected:</span><span class="font-weight-bold text-dark ml-2">{{ $bill->hcp_expected_payment_amount ? '$' . $bill->hcp_expected_payment_amount : '-' }}</span>
                                        @endif
                                    </td>
                                    <td>
                                        <div class="">
                                            @if(!$bill->is_cancelled)
                                                @if($bill->is_signed_by_hcp)
                                                    <div class="d-block text-secondary">
                                                        <i class="fa fa-check"></i>
                                                        HCP Signed
                                                    </div>
                                                @else
                                                    <div moe
                                                         class="d-block {{ $bill->hcp_pro_id !== $pro->id ? 'moe-disabled' : '' }}"
                                                         title="{{ $bill->hcp_pro_id !== $pro->id ? 'Only the bill\'s HCP can sign' : '' }}">
                                                        <a class="" href="" show start>Sign as HCP</a>
                                                        <form url="/api/bill/signAsHcp">
                                                            <input type="hidden" name="uid" value="{{$bill->uid}}">
                                                            <p>Sign this bill as HCP?</p>
                                                            <div class="mb-0">
                                                                <button class="btn btn-success btn-sm" submit>Sign</button>
                                                                <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                                            </div>
                                                        </form>
                                                    </div>
                                                @endif
                                            @endif
                                            @if($bill->is_cancelled)
                                                <div class="d-block text-secondary">
                                                    Cancelled
                                                </div>
                                            @else
                                                <div class="d-block" moe>
                                                    <a class="text-danger" href="" show start>Cancel</a>
                                                    <form url="/api/bill/markCancelled">
                                                        <input type="hidden" name="uid" value="{{$bill->uid}}">
                                                        <p>Cancel this bill?</p>
                                                        <div class="mb-0">
                                                            <button class="btn btn-danger btn-sm" submit>Yes</button>
                                                            <button class="btn btn-default border btn-sm" cancel>No</button>
                                                        </div>
                                                    </form>
                                                </div>
                                            @endif
                                        </div>
                                    </td>
                                </tr>
                            @endforeach
                            </tbody>
                        </table>
                    </div>
                @else
                    <div class="my-3 px-3 d-flex">
                        <p class="font-weight-bold mb-0 text-secondary">No bills in this note</p>
                        @if($patient->has_mcp_done_onboarding_visit === 'YES')
                        <span class="mx-2 text-secondary">|</span>
                        <span moe class="">
                            <a class="" href="" show start>Create Bill</a>
                            <form url="/api/bill/createForNote">
                                <input type="hidden" name="noteUid" value="{{$note->uid}}">
                                <div class="mb-2">
                                    <label for="" class="text-secondary text-sm">Effective Date</label>
                                    <input type="date" name="effectiveDate" class="form-control form-control-sm" value="{{date('Y-m-d')}}" required>
                                </div>
                                <div class="mb-2">
                                    <select autofocus class="form-control" name="code">
                                        <option value="">-- Select Code --</option>
                                        <?php $noteRates = $pro->noteRates(); ?>
                                        @if($noteRates && count($noteRates))
                                            @foreach($noteRates as $noteRate)
                                                <option value="{{ $noteRate->code }}">{{ $noteRate->code }}</option>
                                            @endforeach
                                        @endif
                                    </select>
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason1" placeholder="Reason 1" class="form-control form-control-sm">
                                </div>
                                <div class="mb-2">
                                    <input type="text" name="reason2" placeholder="Reason 2" class="form-control form-control-sm">
                                </div>
                                <div class="">
                                    <button class="btn btn-primary btn-sm" submit>Submit</button>
                                    <button class="btn btn-default border btn-sm" cancel>Cancel</button>
                                </div>
                            </form>
                        </span>
                        @endif
                    </div>
                @endif
            </div>
        </div>
    </div>
    <div class="note-templates-underlay"></div>
    <script>
        (function() {
            function init() {
                $('textarea[rte]').each(function() {

                    $(this).wrap(
                        $('<div class="border-left border-right rte-holder"/>')
                            .attr('data-shortcuts', '{{ $packed }}')
                    );

                    // give a unique id to this editor instance
                    var editorID = Math.ceil(Math.random() * 99999),
                        fieldName = this.name;

                    var ti = $('<input type="hidden" />')
                        .val(this.value)
                        .attr('name', this.name)
                        .insertBefore(this);
                    var ce = $('<div data-editor-id="' + editorID + '" data-field="' + this.name + '"/>')
                        .html(this.value)
                        .insertBefore(this);
                    $(this).remove();

                    var qe = new Quill('[data-editor-id="' + editorID + '"]', {
                        theme: 'snow',
                        modules: {
                            keyboard: {
                                bindings: {
                                    handleEnter: {
                                        key: 13,
                                        handler: function() {
                                            if(!$('.stag-shortcuts:visible').length) return true;
                                        }
                                    }
                                }
                            }
                        }
                    });
                    var toolbar = $(qe.container).prev('.ql-toolbar');

                    // add button for new shortcut
                    var newSCButton = $('<button class="btn bg-white btn-sm btn-default text-primary w-auto px-2 border py-0 ' +
                        'text-sm add-shortcut" data-editor-id="' + editorID + '">+ Shortcut</button>');
                    toolbar.append(newSCButton);

                    qe.on('text-change', function() {
                        ti.val(qe.root.innerHTML);
                    });

                    $(qe.container)
                        .find('.ql-editor[contenteditable]')
                            .attr('data-field', fieldName)
                            .attr('data-editor-id', editorID)
                            .attr('with-shortcuts', 1);

                });

                $('.edit-trigger')
                    .off('click.edit-trigger')
                    .on('click.edit-trigger', function() {
                        let editParent = $(this).closest('.note-section');
                        editParent.toggleClass('edit');
                        if(editParent.is('.edit')) {
                            editParent.siblings('.edit').removeClass('edit');
                            if(editParent.find('[contenteditable]').length) {
                                editParent.find('[contenteditable]').first().focus();
                            }
                            else {
                                editParent.find('textarea:visible').first().focus();
                            }
                        }
                        return false;
                    });

                $('.note-templates-trigger')
                    .off('click.note-templates-trigger')
                    .on('click.note-templates-trigger', function() {
                        $('.note-templates-underlay').show();
                        let container = $(this).closest('.note-section').find('.note-template-container');
                        container.find('.note-template-children').hide();
                        container.find('.note-template-item.selected').removeClass('selected');
                        container.find('.note-template-item[prefix]').removeAttr('prefix');
                        container.find('input[type="checkbox"]').prop('checked', false);
                        container.find('.note-template-output-text').empty();
                        container.show();
                        return false;
                    });

                $('.note-templates-underlay, .note-template-close-trigger')
                    .off('click.note-templates-underlay')
                    .on('click.note-templates-underlay', function() {
                        $('.note-templates-underlay').hide();
                         $('.note-template-container').hide();
                    });

                $('.note-template-item .label')
                    .off('click.note-template-label')
                    .on('click.note-template-label', function() {
                        let item = $(this).closest('.note-template-item');
                        let isChecked = $(this).find('>input[type="checkbox"]').prop('checked');
                        let hasChildren = !!item.find('>.note-template-children').length,
                            childrenShown = item.find('>.note-template-children:visible').length;

                        if(isChecked && hasChildren && !childrenShown) { // just show
                            $('.note-template-children').hide();
                            $(this).parents('.note-template-children').show();
                            item.find('>.note-template-children').show()
                                .find('>textarea,>input[type="number"],>input[type="date"]').first().focus();
                            return false;
                        }

                        $(this).find('>input[type="checkbox"]').prop('checked', !isChecked);
                        isChecked = !isChecked;
                        if(isChecked) {
                            item.addClass('selected');
                        }
                        else {
                            item.removeClass('selected');
                        }
                        $('.note-template-children').hide();
                        $(this).parents('.note-template-children').show();
                        if(isChecked) {
                            item.find('>.note-template-children')
                                .show()
                                .find('>textarea,>input[type="number"],>input[type="date"]')
                                .first().focus();
                        }

                        generateTemplateOutput();

                        return false;
                    });

                $('.note-template-apply-trigger')
                    .off('mousedown.note-templates-apply')
                    .on('mousedown.note-templates-apply', function() {
                        let result = $('.note-template-output-text:visible').first().html();
                        $('.note-templates-underlay').hide();
                        $('.note-template-container').hide();
                        let editor  = $('.ql-editor[contenteditable]').first();
                        result = $.trim(editor.text() !== '' ? editor.html() : '') + result;
                        editor.html(result).focus();
                        return false;
                    });

                $('.note-template-item textarea, .note-template-item input[type="number"], .note-template-item input[type="date"]')
                    .off('input paste change')
                    .on('input paste change', function() {
                        generateTemplateOutput();
                    });

                $('.note-template-item .plus-trigger')
                    .off('click.plus-trigger')
                    .on('click.plus-trigger', function() {
                        let item = $(this).closest('.note-template-item');
                        if(item.attr('prefix') === '(+)') {
                            item.removeAttr('prefix');
                            item.find('>.note-template-text>.label>input[type="checkbox"]').prop('checked', false);
                            item.removeClass('selected');
                        }
                        else {
                            item.attr('prefix', '(+)');
                            item.find('>.note-template-text>.label>input[type="checkbox"]').prop('checked', true);
                            item.addClass('selected');
                        }
                        generateTemplateOutput();
                        return false;
                    });

                $('.note-template-item .minus-trigger')
                    .off('click.plus-trigger')
                    .on('click.plus-trigger', function() {
                        let item = $(this).closest('.note-template-item');
                        if(item.attr('prefix') === '(-)') {
                            item.removeAttr('prefix');
                            item.find('>.note-template-text>.label>input[type="checkbox"]').prop('checked', false);
                            item.removeClass('selected');
                        }
                        else {
                            item.attr('prefix', '(-)');
                            item.find('>.note-template-text>.label>input[type="checkbox"]').prop('checked', true);
                            item.addClass('selected');
                        }
                        generateTemplateOutput();
                        return false;
                    });

            }

            function generateOutputForNode(_node) {
                let template = (_node.attr('prefix') ? _node.attr('prefix') + ' ' : '') + _node.attr('template'),
                    value = template;
                if(value.indexOf('{text}') !== -1) {
                    value = value.replace('{text}',
                        _node
                            .find('>.note-template-children')
                                .find('>textarea,>input[type="number"],>input[type="date"]').first().val());
                }
                else if(value.indexOf('{children}') !== -1) {
                    let values = [];
                    _node.find('>.note-template-children>.note-template-item.selected').each(function() {
                        values.push(generateOutputForNode($(this)));
                    });
                    let combined = '';
                    for (let i = 0; i < values.length; i++) {
                        combined += values[i];
                        if(values.length > 1 && i <= values.length - 2) {
                            if(i === values.length - 2) {
                                combined += ' and ';
                            }
                            else {
                                combined += ', ';
                            }
                        }
                    }
                    value = value.replace('{children}', combined);
                }
                return value;
            }

            function generateTemplateOutput() {
                let container = $('.note-template-container:visible').first();
                if(!container.length) return '';
                let lines = [];
                container.find('>.note-template-item.selected').each(function() {
                    lines.push('<p class="note-template-output-line">' + generateOutputForNode($(this)) + '</p>');
                });
                $('.note-template-output-text:visible').first().html(lines.join(''));
            }

            addMCInitializer('note-single', init);
        })();
    </script>
@endsection

@section('left-nav-content')
    <div class="left-nav-content" id="note-sections-app">
        <div class="note-widget-title px-2 py-1">Note Sections</div>
        <input type="search" class="d-block w-100 border-0 outline-0 px-2 py-1"
               v-model="q" placeholder="Filter">
        <div class="border-top py-1">
            <div v-for="section in sections"
                 v-show="section.title.toLowerCase().indexOf(q.toLowerCase()) !== -1">
                <div class="d-flex pr-1 align-items-center note-widget-item">
                    <span class="mx-2" v-show="section.used">
                        <a class="font-12 text-secondary" href="#"
                           v-on:click.prevent="remove(section.section_uid)">
                            <i class="fa fa-minus-circle"></i>
                        </a>
                    </span>
                    <span class="mx-2" v-show="!section.used">
                        <a class="font-12" href="#"
                           v-on:click.prevent="add(section.uid)">
                            <i class="fa fa-plus-circle"></i>
                        </a>
                    </span>
                    <span class="font-smaller text-ellipsis c-pointer" :title="section.title">
                        @{{section.title}}
                    </span>
                </div>
            </div>
        </div>
    </div>
    <script>
        (function() {
            function initSectionsWidget() {
                var allSections = <?= json_encode($allSections) ?>;
                new Vue({
                    el: '#note-sections-app',
                    delimiters: ['@{{', '}}'],
                    data: {
                        q: '',
                        sections: allSections
                    },
                    methods: {
                        add: function(_uid) {
                            $.post('/api/section/create', {
                                noteUid: '{{$note->uid}}',
                                summaryHtml: '',
                                contentData: '',
                                sectionTemplateUid: _uid,
                            }, function(_data) {
                                if(_data) {
                                    if(_data.success) {
                                        fastReload();
                                    }
                                    else {
                                        toastr.error(_data.message);
                                    }
                                }
                                else {
                                    toastr.error('Unable to add section!');
                                }
                            }, 'json');
                        },
                        remove: function(_uid) {
                            $.post('/api/section/deactivate', {
                                uid: _uid,
                                memo: 'Deactivated from note',
                            }, function(_data) {
                                if(_data) {
                                    if(_data.success) {
                                        fastReload();
                                    }
                                    else {
                                        toastr.error(_data.message);
                                    }
                                }
                                else {
                                    toastr.error('Unable to remove section!');
                                }
                            }, 'json');
                        }
                    }
                });
            }
            addMCInitializer('sections-widget', initSectionsWidget);
        })();
    </script>
@endsection
